@@ -28,6 +28,10 @@ void BSAMCMCResult::add(Theta theta_cur) {
 
 // TODO: avoid transposing
 List BSAMCMCResult::result() const {
+  NumericVector acc(this->acc.begin(), this->acc.end());
+  const std::string acc_names[] = {"alpha", "beta.z", "sigma.sq", "tau.sq",
+                            "beta.u.gamma.x", "gamma.z"};
+  acc.names() = std::vector<std::string>(acc_names, acc_names+6);
   return List::create(_["alpha"] = trans(alphas),
                       _["beta.z"] = trans(beta_zs),
                       _["gamma.z"] = trans(gamma_zs),
